@@ -123,7 +123,7 @@ class Intents(BaseFlags):
 
     @classmethod
     def all(cls: Type[Intents]) -> Intents:
-        """A factory method that creates a :class:`Intents` with everything enabled."""
+        """一个工厂方法，它创建一个 :class:`Intents` 并启用所有内容。"""
         value = 0
         for bits in cls.VALID_FLAGS.values():
             value |= bits
@@ -133,14 +133,15 @@ class Intents(BaseFlags):
 
     @classmethod
     def none(cls: Type[Intents]) -> Intents:
-        """A factory method that creates a :class:`Intents` with everything disabled."""
+        """一个工厂方法，它创建一个禁用一切的 :class:`Intents` 。"""
         self = cls.__new__(cls)
         self.value = self.DEFAULT_VALUE
         return self
 
     @classmethod
     def default(cls: Type[Intents]) -> Intents:
-        """一个工厂方法，它创建一个 :class:`Intents`，除了 :attr:`presences` 和 :attr:`members` 之外的所有内容都启用。
+        """一个工厂方法，它创建一个 :class:`Intents`，
+        除了 :attr:`guilds`, :attr:`members` 和 :attr:`at_guild_messages` 之外的所有内容都禁用。
         """
         self = cls.none()
         self.guilds = True
@@ -241,6 +242,15 @@ class Intents(BaseFlags):
 
     @flag_value
     def audio(self):
+        """:class:`bool`: 公会提及机器人的消息相关事件是否开启。
+
+        这对应于以下事件：
+
+        - :func:`on_audio_start`
+        - :func:`on_audio_stop`
+        - :func:`on_mic_start`
+        - :func:`on_mic_stop`
+        """
         return 1 << 29
 
     @flag_value
